@@ -27,7 +27,7 @@ import (
 	"time"
 
 	corev1 "k8s.io/api/core/v1"
-	"knative.dev/serving/pkg/network"
+	network "knative.dev/networking/pkg"
 )
 
 // HTTPProbeConfigOptions holds the HTTP probe config options
